@@ -64,7 +64,7 @@ class ClientLoop(object):
             return
         for name in os.listdir(self.dir):
             file_path = os.path.join(self.dir, name)
-            if os.path.isfile(name):
+            if os.path.isfile(file_path):
                 os.remove(file_path)
                 click.echo("delete name: [{}]".format(name))
 
